@@ -501,6 +501,8 @@ xfce_displays_helper_get_matching_profile (XfceDisplaysHelper *helper)
         xfsettings_dbg (XFSD_DEBUG_DISPLAYS, "Found %d matching display profiles.", g_list_length (profiles));
     }
 
+    g_list_free_full (profiles, g_free);
+
     return NULL;
 }
 
@@ -629,12 +631,12 @@ xfce_displays_helper_screen_on_event (GdkXEvent *xevent,
                         crtc = xfce_displays_helper_find_usable_crtc (helper, output);
                         if (crtc)
                         {
-                            crtc->mode = output->preferred_mode;
+                            crtc->mode = (autoconnect_mode > 0) ? output->preferred_mode : None;
                             crtc->rotation = RR_Rotate_0;
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
                             if ((crtc->x > gdk_screen_width() + 1) || (crtc->y > gdk_screen_height() + 1)
-                                || autoconnect_mode == 2) {
-G_GNUC_END_IGNORE_DEPRECATIONS
+                                || autoconnect_mode == 2)
+                            {
                                 crtc->x = crtc->y = 0;
                             }
                             /* Extend to the right if configured */
@@ -643,6 +645,7 @@ G_GNUC_END_IGNORE_DEPRECATIONS
                                 crtc->x = helper->width - crtc->width;
                                 crtc->y = 0;
                             } /* else - leave values from last time we saw the monitor */
+G_GNUC_END_IGNORE_DEPRECATIONS
                             /* set width and height */
                             for (j = 0; j < helper->resources->nmode; ++j)
                             {
